# Command

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**arguments** | [**list[Argument]**](Argument.md) |  | [optional] 
**cartesian** | **bool** |  | [optional] 
**deprecated** | **bool** |  | [optional] 
**description** | **str** |  | [optional] 
**execution** | **bool** |  | [optional] 
**hidden** | **bool** |  | [optional] 
**important** | [**list[Important]**](Important.md) |  | [optional] 
**name** | **str** |  | [optional] 
**outputs** | [**list[Output]**](Output.md) |  | [optional] 
**permitted** | **bool** |  | [optional] 
**sensitive** | **bool** |  | [optional] 
**timeout** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


